@@ -1,6 +1,6 @@
 /* mpc_set -- Set a complex number from another complex number.
 
-Copyright (C) 2002 Andreas Enge, Paul Zimmermann
+Copyright (C) 2002, 2009 Andreas Enge, Paul Zimmermann, Philippe Th\'eveny
 
 This file is part of the MPC Library.
 
@@ -19,9 +19,7 @@ along with the MPC Library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 MA 02111-1307, USA. */
 
-#include "gmp.h"
-#include "mpfr.h"
-#include "mpc.h"
+#include "mpc-impl.h"
 
 int
 mpc_set (mpc_ptr a, mpc_srcptr b, mpc_rnd_t rnd)
